@@ -18,24 +18,11 @@ use Try::Tiny;
 
 sub get_redis
 {
-    my $redis = shift;
     my @args = @_;
 
-    if ( $redis ) {
-        if ( ref( $redis ) eq 'Test::RedisServer' ) {
-            $redis->stop;
-        } elsif ( ref( $redis ) eq 'Redis' ) {
-            $redis->quit;
-        }
-        undef $redis;
-        sleep 1;
-    }
-
-    my $error;
+    my ( $redis, $error );
     for ( 1..3 )
     {
-# !!!!
-diag "attempt = $_";
         try
         {
             $redis = Test::RedisServer->new( @args );
@@ -43,13 +30,11 @@ diag "attempt = $_";
         catch
         {
             $error = $_;
-# !!!!
-diag "error: $error";
         };
         last unless $error;
         sleep 1;
     }
-    BAIL_OUT $error if $error;
+    BAIL_OUT "failed to launch redis-server" if $error;
 
     return $redis;
 }
